#
# spec file for package python-uproot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global modname uproot
Name:           python-uproot
Version:        5.3.3
Release:        1.5
Summary:        ROOT I/O in pure Python and Numpy
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/scikit-hep/uproot5
Source0:        https://files.pythonhosted.org/packages/source/u/uproot/uproot-%{version}.tar.gz
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cramjam
Requires:       python-fsspec
Requires:       python-numpy >= 1.13.1
Requires:       python-packaging
Recommends:     python-awkward
Suggests:       python-boost-histogram
Suggests:       python-cupy
Suggests:       python-hist
Suggests:       python-lz4
Suggests:       python-pandas
Suggests:       python-xrootd
Suggests:       python-zstandard
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module RangeHTTPServer}
BuildRequires:  %{python_module awkward}
BuildRequires:  %{python_module cramjam}
BuildRequires:  %{python_module lz4}
BuildRequires:  %{python_module numpy >= 1.13.1}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module scikit-hep-testdata >= 0.4.38}
BuildRequires:  %{python_module xxhash}
BuildRequires:  %{python_module boost-histogram >= 0.13 if (%python-base without python2-base)}
# /SECTION
# python-awkward no longer builds for 32-bit archs
ExcludeArch:    %{ix86} %{arm32}
%python_subpackages

%description
Uproot is a reader and a writer of the ROOT file format using only Python and
Numpy. Unlike the standard C++ ROOT implementation, Uproot is only an I/O
library, primarily intended to stream data into machine learning libraries in
Python. It uses Numpy to cast blocks of data from the ROOT file as Numpy
arrays.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export HOME=$PWD
export PYTEST_DEBUG_TEMPROOT=$(mktemp -d -p ./)
# Network based tests
skip_network_tests=\
("-k" "not (test_0001_source_class or test_0006_notify_when_downloaded \
            or test_0007_single_chunk_interface or test_0692_fsspec_reading \
            or test_split_ranges_if_large_file_in_http \
            or test_descend_into_path_classname_of)" \
)
if [ $(getconf LONG_BIT) -eq 32 ]; then
# pandas tests assume 64bit types
skiptests32="(test_jagged_pandas or test_pandas_vector_TLorentzVector or test_iterate_pandas_2 or test_function_iterate_pandas_2 or test_0430)"
fi
# Skip test_decompression_executor_for_dask until we have dask-awkward packaged
%pytest "${skip_network_tests[@]} ${skiptests32} and not (test_decompression_executor_for_dask or test_dask_duplicated_keys)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/%{modname}
%{python_sitelib}/%{modname}-%{version}*-info

%changelog
* Sun Apr 28 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.3:
  * feat: add support for std::bitset (gh#scikit-hep/uproot5#1182).
  * fix: dask failing for TTrees with duplicate TBranch names
    (gh#scikit-hep/uproot5#1189).
  * fix: update for NumPy 2.0 (gh#scikit-hep/uproot5#1195).
- Disable a few more network based or awkward_dask dependent
  tests.
* Sat Feb 24 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.1:
  * Loosen the version constraint on cramjam
- Changes from version 5.3.0:
  * feat: use cramjam for lzma, lz4, and zstd, opt-in use of isal
    for zlib (gh#scikit-hep/uproot5#1090).
  * feat: expose decompression_executor and
    interpretation_executor in uproot dask
    (gh#scikit-hep/uproot5#1120).
  * fix: missing '_fh' and '_file' attributes after unpickling
    (gh#scikit-hep/uproot5#1118).
  * fix: fix dask_write docs (gh#scikit-hep/uproot5#1122).
  * fix: attempt to concatenate numpy and awkward arrays
    (gh#scikit-hep/uproot5#1114).
  * fix: test suite creates files not in tmp_path
    (gh#scikit-hep/uproot5#1123).
  * fix: allow colon in key names (gh#scikit-hep/uproot5#1127).
  * fix: allow writing generic UHI-compatible histograms
    (gh#scikit-hep/uproot5#1128).
- New dependencies:
  * BuildRequires: python-hatch_vcs.
  * (Build)Requires: python-cramjam.
- Update URL tag.
* Mon Jan 15 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.1:
  * feat: supply a pre-calculated base form to avoid file opening
    [gh#scikit-hep/uproot5#1077].
  * test: xrootd server fixture [gh#scikit-hep/uproot5#1076].
  * test: fsspec cache [gh#scikit-hep/uproot5#1075].
- pytest: Use -k to skip over network based tests as "-m network"
  was no longer working.
- New BuildRequires: python-RangeHTTPServer.
* Fri Oct 13 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.13:
  * feat: add TLeafC - string - writing support
    [gh#scikit-hep/uproot5#940].
  * feat: adding a very basic FSSpecSource
    [gh#scikit-hep/uproot5#967].
  * fix: inverted axes for variances of 2D weighted histograms
    when transformed to hist [gh#scikit-hep/uproot5#965].
  * fix: pull out .data from NumpyArray
    [gh#scikit-hep/uproot5#985].
- Delete a test file that causes import errors because python-hist
  is not packaged for the distro.
* Sun Oct  8 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.12:
  * fix: changelog script ignores releases past 5.0.0rc2
    [gh#scikit-hep/uproot5#935].
  * fix: clamp start and stop [gh#scikit-hep/uproot5#941].
  * fix: get package import messages up-to-date
    [gh#scikit-hep/uproot5#947].
  * fix: tests were failing because dask_awkward.lib.testutils
    needs pyarrow [gh#scikit-hep/uproot5#957].
  * fix: add minimimal emscripten support via non-HTTP sources
    [gh#scikit-hep/uproot5#956].
  * fix: remove pyarrow import as a dependence coming from
    dask-awkward in tests [gh#scikit-hep/uproot5#961].
* Sun Sep 17 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.11:
  * Support reading from S3 [gh#scikit-hep/uproot5#916].
  * fix: pandas and double nested vectors issue 885
    [gh#scikit-hep/uproot5#912].
  * fix: don't assume Uproot is in global scope in TPython::Eval
    [gh#scikit-hep/uproot5#927].
  * fix: expressions failing in pandas issue 922
    [gh#scikit-hep/uproot5#930].
* Mon Jul  3 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.9:
  * fix: if using form remapping start off with full list of
    remapped columns [gh#scikit-hep/uproot5#905].
- Now BuildRequires scikit-hep-testdata >= 0.4.31 for tests.
- For checks, some tests now require a writable tmp dir; create
  one in working dir using mktemp and set PYTEST_DEBUG_TEMPROOT.
* Sat May 27 2023 Dirk Müller <dmueller@suse.com>
- reenable build for python 3.11, dask is available
* Thu May  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.7:
  * Previously, uproot.dask would default to step_size="100 MB" if
    open_files=True and whole-file-steps (limit on step size) if
    open_files=False. Now both open_files cases default to
    steps_per_file=1 (whole-file-steps) for uniformity.
  * feat: add in capability for blindly splitting files into
    chunks for dask (gh#scikit-hep/uproot5#876).
- Drop tests.tar.xz as additional Source as test files are now
  included with upstream pypi tarball; drop associated _service.
- Update required version of scikit-hep-testdata to 0.4.30 for
  tests.
* Sun Mar 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Disable building against python3.11 until numba -- and dask --
  is compatible.
- Disable 32-bit builds since python-awkward no longer builds for
  those archs.
* Wed Mar  1 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file
* Thu Feb 23 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.3:
  * feat: Infrastructure for writing of RNTuple (incomplete
    functionality)
  * feat: [WIP] RNTuple Basic Writing
  * fix: an uproot.dask test was wrong; revealed by new dask-
    awkward.
  * fix: separate AwkwardForth machine for each TBranch context.
  * fix: separate ZstdDecompressor for each thread.
  * fix: uproot.dask: Protect against `branches=None` in
    `project_columns`
  * fix: AsStridedObjects.awkward_form was still including the
    '@' members.
  * fix: protect Uproot's 'project_columns' from Dask node names.
  * Uproot version 5 has a few major new features, one removal
    (`uproot.lazy`), and is based on Awkward Array version 2
    instead of version 1.
  * @kkothari2001 upgraded Uproot from Awkward version 1 to
    version 2, the major part of which was replacing
    `uproot.lazy`, which is based on Awkward 1's virtual and
    partitioned lazy arrays, with the new Dask collection, dask-
    awkward. The entry point for this function is `uproot.dask`.
  * @kkothari2001 also simplified Uproot's Pandas backend, which
    used to "explode" ragged arrays from ROOT into Pandas
    DataFrames with a non-trivial MultiIndex. Now, it takes
    advantage of awkward-pandas to put ragged (and more complex)
    Awkward Arrays directly into Pandas columns.
  * If you want the old behavior, you can read data using
    `library="ak"` to get an Awkward Array, and use
    ak.to_dataframe to "explode" the data into a MultiIndex.
  * @aryan26roy added a new code path to the TTree-reading
    routines to read them with AwkwardForth instead of pure
    Python. Users won't see any _interface_ changes due to this
    code, but the performance of reading TBranches with
    `AsObject` or `AsStrings` Interpretations should be orders of
    magnitude faster. For example, `std::vector>` reading is now
    400× faster.
  * @Moelf added a complete reader of RNTuple data with most of
    an RNTuple-writer in an unmerged pull request (#705).
    Although the RNTuple format is still in development, this is
    a very good start at reading RNTuple data, whose structure is
    a close match to Awkward Arrays (so the translation is more
    one-to-one than it is for TTrees, for instance).
  * feat: move to hatchling
  * feat: `from_map` like optimization for dask arrays
  * feat: Finalizing AwkwardForth reader for Uproot
  * feat: implemented NON-memberwise deserialization for AsMap.
  * feat: Added column_projection optimization
  * feat: support categorical axes on boost histograms
  * feat: warn about TBranch name, alias name conflict.
  * feat: any Mapping assigned to a WritableDirectory is
    interpreted as a TTree or failure, no fall-through.
  * feat: add 'interp_options' mechanism and ak_add_doc.
  * feat: Use awkward pandas, instead of the existing code that
    explodes Pandas Dataframes
  * feat: made 'very optional' arguments keyword-only
  * feat: adjust for name change in scikit-hep/awkward#1919.
  * fix: depend on packaging, not setuptools vendored packaging
  * fix: Avoid triggering temporary dask-awkward/awkward
    incompatibility.
  * fix: Do not write incorrect fSumw2 in histograms (v5).
  * fix: Fixes uproot.dask bug with empty branches
  * fix: Use `from_map` optimization for delayed numpy arrays and
    add tests with empty branches for the same
  * fix: use ctx manager to ensure resources are freed
  * fix: ReadOnlyDirectory should provide the largest abs(cycle)
    when cycle is unspecified, not the largest cycle.
  * fix: regularize ROOT type aliases to C fundamental type
    names.
  * fix: avoid empty TBasket issue in embedded TBasket
  * fix: don't use Awkward in test_0751 that doesn't need it
  * fix: working TList serialization
  * fix: histogram weights not handled correctly in hist / boost
    conversion
  * perf: streamline metadata handling for TBranch name lookup
    and uproot.dask
  * fix: ensure AwkwardForth fallback path is tested without
    history.
  * fix: all AwkwardForth Forms now agree with awkward_form
    method output.
  * fix: Uproot tests now work with Awkward 2.0.0.
- drop uproot-use-packaging-module.patch (upstream)
* Wed Aug 10 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.3.4:
  * fixed uninitialized attributes of ReadOnlyDirectory
    [gh#scikit-hep/uproot4#661].
- Refresh uproot-use-packaging-module.patch to correct use of
  packaging.version.
* Mon Jul  4 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.3.3:
  * Fixed an O(n²) scaling bug in getting data from TDirectories
    so that now it's O(n) [gh#scikit-hep/uproot4#639].
* Tue Jun 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.3.0:
  * Added a TMatrixTSym model (long stalled PR):
    gh#scikit-hep/uproot4#484.
  * Restored the argument list of Interpretation.awkward_form, a
    public function: PR gh#scikit-help/uproot4#618.
- Refresh tests tarball with updated dir from git repository.
* Mon Mar 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.2.2:
  * Restore performance hack for AsArray(True, False,
    AsVector(False, dtype)) [gh#scikit-hep/uproot4#572].
* Tue Mar  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.2.1:
  * Added a rule to skip parsing Float16/Double32 TBranch titles
    if the title is not parsable (and just assume default number
    of bits) [gh#scikit-hep/uproot4#561].
  * Removed references to deprecated distutils and Pandas
    Int64Index [gh#scikit-hep/uproot4#564].
  * Removed the rule that interpreted fBits as 1 byte (it's 4
    bytes everywhere except in some branches of some Delphes
    files) [gh#scikit-hep/uproot4#570].
- Add uproot-use-packaging-module.patch -- Use packaging module
  directly instead of calling it via setup.extern; the latter does
  not work on openSUSE directly.
- Introduce Requires and BuildRequires (for tests) on
  python-packaging in light of above patch.
- Update tests.tar.xz to tagged 4.2.1 version.
* Tue Feb 15 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.2.0:
  * Drop Python2isms from the codebase:
    [gh#scikit-hep/uproot#526].
  * Make writing to Python file handles work (fixed a
    half-finished, forgotten implementation):
    [gh#scikit-hep/uproot#538].
  * Fix cut jagged-array corner-case in library="pd".
  * Fix a case in which the instance version is 0, but the
    streamer version is not: [gh#scikit-hep/uproot#537].
  * Fix uproot.WritableTTree.extend when the metadata needs to be
    rewritten: [gh#scikit-hep/uproot#547].
  * When checking to see if something in file["name"] = something
    is an Awkward Array or Pandas DataFrame for creating a TTree,
    also check for superclasses (the whole mro):
    [gh#scikit-hep/uproot#557].
- Sync tests tarball with version 4.2.0.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.1.9:
  * [gh#scikit-hep/uproot#523] docs: add pfackeldey as a
    contributor for code.
  * [gh#scikit-hep/uproot#522] [pre-commit.ci] pre-commit
    autoupdate.
  * [gh#scikit-hep/uproot#506] add uproot.model.TTable.data
    getter.
  * [gh#scikit-hep/uproot#521] Dynamic classes can’t be ABC
    subclasses, such as Sequence.
  * [gh#scikit-hep/uproot#519] [MemmapSource] Remove
    unnecessary(?) copies.
  * [gh#scikit-hep/uproot#517] Be more careful about identifying
    pd.DataFrame.
- Update tests.tar.xz to version 4.1.9.
- Disable an additional test on 32-bit that depends on 64-bit long.
* Fri Jul 16 2021 Ben Greiner <code@bnavigator.de>
- Update to v4.0.11
  * see https://uproot.readthedocs.io/en/latest/changelog.html
- Update runtime and builtime requirements:
  * Add awkward as recommendation (upstream: "highly recommended")
  * Add other optional package as suggestions
  * BuildRequire what is available and used for offline tests
- Skip some pandas tests which test for 64bit types on 32bit builds
- use the pytest network mark in order to skip network tests on obs
- add a network mark to test_0220 -- gh#scikit-hep/uproot4#396
* Wed Apr 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable builds for python 3.6: no numpy.
* Sun Dec 13 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Package tests subdir from upstream git since they are missing
  from the PyPI src tarballs.
